# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: editor.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2
from . import communities_pb2 as communities__pb2
from . import postal_verification_pb2 as postal__verification__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x65\x64itor.proto\x12\x13org.couchers.editor\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\x1a\x11\x63ommunities.proto\x1a\x19postal_verification.proto\"s\n\x12\x43reateCommunityReq\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x16\n\x0eparent_node_id\x18\x04 \x01(\x03\x12\x11\n\tadmin_ids\x18\x05 \x03(\x03\x12\x0f\n\x07geojson\x18\x06 \x01(\t\"v\n\x12UpdateCommunityReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x16\n\x0eparent_node_id\x18\x04 \x01(\x03\x12\x0f\n\x07geojson\x18\x05 \x01(\t\"L\n#ListEventCommunityInviteRequestsReq\x12\x11\n\tpage_size\x18\x01 \x01(\r\x12\x12\n\npage_token\x18\x02 \x01(\t\"\xa2\x01\n\x1b\x45ventCommunityInviteRequest\x12)\n!event_community_invite_request_id\x18\x01 \x01(\x03\x12\x0f\n\x07user_id\x18\x02 \x01(\x03\x12\x11\n\tevent_url\x18\x03 \x01(\t\x12\x1e\n\x16\x61pprox_users_to_notify\x18\x04 \x01(\r\x12\x14\n\x0c\x63ommunity_id\x18\x05 \x01(\x03\"\x82\x01\n#ListEventCommunityInviteRequestsRes\x12\x42\n\x08requests\x18\x01 \x03(\x0b\x32\x30.org.couchers.editor.EventCommunityInviteRequest\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"b\n$DecideEventCommunityInviteRequestReq\x12)\n!event_community_invite_request_id\x18\x01 \x01(\x03\x12\x0f\n\x07\x61pprove\x18\x02 \x01(\x08\"&\n$DecideEventCommunityInviteRequestRes\"H\n\x1bSendBlogPostNotificationReq\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x62lurb\x18\x03 \x01(\t\"n\n\x14MakeUserVolunteerReq\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\x1c\n\x14started_volunteering\x18\x03 \x01(\t\x12\x19\n\x11hide_on_team_page\x18\x04 \x01(\x08\"\xcd\x02\n\x12UpdateVolunteerReq\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12*\n\x04role\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08sort_key\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12:\n\x14started_volunteering\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\x14stopped_volunteering\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x11show_on_team_page\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1b\n\x13reinstate_volunteer\x18\x07 \x01(\x08\")\n\x11ListVolunteersReq\x12\x14\n\x0cinclude_past\x18\x01 \x01(\x08\"\x8b\x03\n\tVolunteer\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08username\x18\x03 \x01(\t\x12\x17\n\x0fis_board_member\x18\x04 \x01(\x08\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\x10\n\x08location\x18\x06 \x01(\t\x12\x0b\n\x03img\x18\x07 \x01(\t\x12\x15\n\x08sort_key\x18\x08 \x01(\x01H\x00\x88\x01\x01\x12\x1c\n\x14started_volunteering\x18\t \x01(\t\x12!\n\x14stopped_volunteering\x18\n \x01(\tH\x01\x88\x01\x01\x12\x19\n\x11show_on_team_page\x18\x0b \x01(\x08\x12\x16\n\tlink_type\x18\x0c \x01(\tH\x02\x88\x01\x01\x12\x16\n\tlink_text\x18\r \x01(\tH\x03\x88\x01\x01\x12\x15\n\x08link_url\x18\x0e \x01(\tH\x04\x88\x01\x01\x42\x0b\n\t_sort_keyB\x17\n\x15_stopped_volunteeringB\x0c\n\n_link_typeB\x0c\n\n_link_textB\x0b\n\t_link_url\"G\n\x11ListVolunteersRes\x12\x32\n\nvolunteers\x18\x01 \x03(\x0b\x32\x1e.org.couchers.editor.Volunteer\"9\n\x10ListPostcardsReq\x12\x11\n\tpage_size\x18\x01 \x01(\r\x12\x12\n\npage_token\x18\x02 \x01(\t\"\x91\x03\n\x0cPostcardInfo\x12&\n\x1epostal_verification_attempt_id\x18\x01 \x01(\x03\x12\x0f\n\x07user_id\x18\x02 \x01(\x03\x12\x10\n\x08username\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12N\n\x06status\x18\x05 \x01(\x0e\x32>.org.couchers.api.postal_verification.PostalVerificationStatus\x12\x44\n\x07\x61\x64\x64ress\x18\x06 \x01(\x0b\x32\x33.org.couchers.api.postal_verification.PostalAddress\x12+\n\x07\x63reated\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10postcard_sent_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bverified_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"a\n\x10ListPostcardsRes\x12\x34\n\tpostcards\x18\x01 \x03(\x0b\x32!.org.couchers.editor.PostcardInfo\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"@\n\x16\x44ownloadPostcardPdfReq\x12&\n\x1epostal_verification_attempt_id\x18\x01 \x01(\x03\"%\n\x16\x44ownloadPostcardPdfRes\x12\x0b\n\x03pdf\x18\x01 \x01(\x0c\x32\xf5\x08\n\x06\x45\x64itor\x12\x65\n\x0f\x43reateCommunity\x12\'.org.couchers.editor.CreateCommunityReq\x1a\'.org.couchers.api.communities.Community\"\x00\x12\x65\n\x0fUpdateCommunity\x12\'.org.couchers.editor.UpdateCommunityReq\x1a\'.org.couchers.api.communities.Community\"\x00\x12\x98\x01\n ListEventCommunityInviteRequests\x12\x38.org.couchers.editor.ListEventCommunityInviteRequestsReq\x1a\x38.org.couchers.editor.ListEventCommunityInviteRequestsRes\"\x00\x12\x9b\x01\n!DecideEventCommunityInviteRequest\x12\x39.org.couchers.editor.DecideEventCommunityInviteRequestReq\x1a\x39.org.couchers.editor.DecideEventCommunityInviteRequestRes\"\x00\x12\x66\n\x18SendBlogPostNotification\x12\x30.org.couchers.editor.SendBlogPostNotificationReq\x1a\x16.google.protobuf.Empty\"\x00\x12`\n\x11MakeUserVolunteer\x12).org.couchers.editor.MakeUserVolunteerReq\x1a\x1e.org.couchers.editor.Volunteer\"\x00\x12\\\n\x0fUpdateVolunteer\x12\'.org.couchers.editor.UpdateVolunteerReq\x1a\x1e.org.couchers.editor.Volunteer\"\x00\x12\x62\n\x0eListVolunteers\x12&.org.couchers.editor.ListVolunteersReq\x1a&.org.couchers.editor.ListVolunteersRes\"\x00\x12_\n\rListPostcards\x12%.org.couchers.editor.ListPostcardsReq\x1a%.org.couchers.editor.ListPostcardsRes\"\x00\x12q\n\x13\x44ownloadPostcardPdf\x12+.org.couchers.editor.DownloadPostcardPdfReq\x1a+.org.couchers.editor.DownloadPostcardPdfRes\"\x00\x1a\x04\x88\xb5\x18\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'editor_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_EDITOR']._loaded_options = None
  _globals['_EDITOR']._serialized_options = b'\210\265\030\005'
  _globals['_CREATECOMMUNITYREQ']._serialized_start=196
  _globals['_CREATECOMMUNITYREQ']._serialized_end=311
  _globals['_UPDATECOMMUNITYREQ']._serialized_start=313
  _globals['_UPDATECOMMUNITYREQ']._serialized_end=431
  _globals['_LISTEVENTCOMMUNITYINVITEREQUESTSREQ']._serialized_start=433
  _globals['_LISTEVENTCOMMUNITYINVITEREQUESTSREQ']._serialized_end=509
  _globals['_EVENTCOMMUNITYINVITEREQUEST']._serialized_start=512
  _globals['_EVENTCOMMUNITYINVITEREQUEST']._serialized_end=674
  _globals['_LISTEVENTCOMMUNITYINVITEREQUESTSRES']._serialized_start=677
  _globals['_LISTEVENTCOMMUNITYINVITEREQUESTSRES']._serialized_end=807
  _globals['_DECIDEEVENTCOMMUNITYINVITEREQUESTREQ']._serialized_start=809
  _globals['_DECIDEEVENTCOMMUNITYINVITEREQUESTREQ']._serialized_end=907
  _globals['_DECIDEEVENTCOMMUNITYINVITEREQUESTRES']._serialized_start=909
  _globals['_DECIDEEVENTCOMMUNITYINVITEREQUESTRES']._serialized_end=947
  _globals['_SENDBLOGPOSTNOTIFICATIONREQ']._serialized_start=949
  _globals['_SENDBLOGPOSTNOTIFICATIONREQ']._serialized_end=1021
  _globals['_MAKEUSERVOLUNTEERREQ']._serialized_start=1023
  _globals['_MAKEUSERVOLUNTEERREQ']._serialized_end=1133
  _globals['_UPDATEVOLUNTEERREQ']._serialized_start=1136
  _globals['_UPDATEVOLUNTEERREQ']._serialized_end=1469
  _globals['_LISTVOLUNTEERSREQ']._serialized_start=1471
  _globals['_LISTVOLUNTEERSREQ']._serialized_end=1512
  _globals['_VOLUNTEER']._serialized_start=1515
  _globals['_VOLUNTEER']._serialized_end=1910
  _globals['_LISTVOLUNTEERSRES']._serialized_start=1912
  _globals['_LISTVOLUNTEERSRES']._serialized_end=1983
  _globals['_LISTPOSTCARDSREQ']._serialized_start=1985
  _globals['_LISTPOSTCARDSREQ']._serialized_end=2042
  _globals['_POSTCARDINFO']._serialized_start=2045
  _globals['_POSTCARDINFO']._serialized_end=2446
  _globals['_LISTPOSTCARDSRES']._serialized_start=2448
  _globals['_LISTPOSTCARDSRES']._serialized_end=2545
  _globals['_DOWNLOADPOSTCARDPDFREQ']._serialized_start=2547
  _globals['_DOWNLOADPOSTCARDPDFREQ']._serialized_end=2611
  _globals['_DOWNLOADPOSTCARDPDFRES']._serialized_start=2613
  _globals['_DOWNLOADPOSTCARDPDFRES']._serialized_end=2650
  _globals['_EDITOR']._serialized_start=2653
  _globals['_EDITOR']._serialized_end=3794
# @@protoc_insertion_point(module_scope)



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import threads_pb2
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class ThreadsStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    GetThread: grpc.UnaryUnaryMultiCallable[threads_pb2.GetThreadReq, threads_pb2.GetThreadRes]
    """The same API is used regardless of level. All posts are using the same id namespace.

    Get non-deleted posts belonging to a thread, sorted in reverse time order.
    """
    PostReply: grpc.UnaryUnaryMultiCallable[threads_pb2.PostReplyReq, threads_pb2.PostReplyRes]
    """Post a new comment on a thread. The post can not be changed or deleted after posting.
    Throws NOT_FOUND if thread_id corresponds to a nesting level 3 reply, since no futher nesting is allowed.
    """
    UpdateReply: grpc.UnaryUnaryMultiCallable[threads_pb2.UpdateReplyReq, threads_pb2.Reply]
    """Update a comment/reply; only the author can edit."""
    DeleteReply: grpc.UnaryUnaryMultiCallable[threads_pb2.DeleteReplyReq, google.protobuf.empty_pb2.Empty]
    """Delete a comment/reply; only the author can delete."""

class ThreadsServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetThread(
        self,
        request: threads_pb2.GetThreadReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> threads_pb2.GetThreadRes:
        """The same API is used regardless of level. All posts are using the same id namespace.

        Get non-deleted posts belonging to a thread, sorted in reverse time order.
        """

    @abc.abstractmethod
    def PostReply(
        self,
        request: threads_pb2.PostReplyReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> threads_pb2.PostReplyRes:
        """Post a new comment on a thread. The post can not be changed or deleted after posting.
        Throws NOT_FOUND if thread_id corresponds to a nesting level 3 reply, since no futher nesting is allowed.
        """

    @abc.abstractmethod
    def UpdateReply(
        self,
        request: threads_pb2.UpdateReplyReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> threads_pb2.Reply:
        """Update a comment/reply; only the author can edit."""

    @abc.abstractmethod
    def DeleteReply(
        self,
        request: threads_pb2.DeleteReplyReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Delete a comment/reply; only the author can delete."""

def add_ThreadsServicer_to_server(servicer: ThreadsServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import conversations_pb2
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _HostRequestSortBy:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _HostRequestSortByEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_HostRequestSortBy.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    HOST_REQUEST_SORT_BY_LAST_ACTIVE: _HostRequestSortBy.ValueType  # 0
    HOST_REQUEST_SORT_BY_FROM_DATE: _HostRequestSortBy.ValueType  # 1

class HostRequestSortBy(_HostRequestSortBy, metaclass=_HostRequestSortByEnumTypeWrapper): ...

HOST_REQUEST_SORT_BY_LAST_ACTIVE: HostRequestSortBy.ValueType  # 0
HOST_REQUEST_SORT_BY_FROM_DATE: HostRequestSortBy.ValueType  # 1
Global___HostRequestSortBy: typing_extensions.TypeAlias = HostRequestSortBy

class _HostRequestQuality:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _HostRequestQualityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_HostRequestQuality.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    HOST_REQUEST_QUALITY_UNSPECIFIED: _HostRequestQuality.ValueType  # 0
    HOST_REQUEST_QUALITY_LOW: _HostRequestQuality.ValueType  # 1
    HOST_REQUEST_QUALITY_OKAY: _HostRequestQuality.ValueType  # 2
    HOST_REQUEST_QUALITY_HIGH: _HostRequestQuality.ValueType  # 3

class HostRequestQuality(_HostRequestQuality, metaclass=_HostRequestQualityEnumTypeWrapper): ...

HOST_REQUEST_QUALITY_UNSPECIFIED: HostRequestQuality.ValueType  # 0
HOST_REQUEST_QUALITY_LOW: HostRequestQuality.ValueType  # 1
HOST_REQUEST_QUALITY_OKAY: HostRequestQuality.ValueType  # 2
HOST_REQUEST_QUALITY_HIGH: HostRequestQuality.ValueType  # 3
Global___HostRequestQuality: typing_extensions.TypeAlias = HostRequestQuality

@typing.final
class CreateHostRequestReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_USER_ID_FIELD_NUMBER: builtins.int
    FROM_DATE_FIELD_NUMBER: builtins.int
    TO_DATE_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    PUBLIC_TRIP_ID_FIELD_NUMBER: builtins.int
    host_user_id: builtins.int
    from_date: builtins.str
    """dates as "yyyy-mm-dd", in the timezone of the host"""
    to_date: builtins.str
    text: builtins.str
    public_trip_id: builtins.int
    """If set, this host request is being created in response to a public trip.
    The role is reversed: the "host" is offering to host the public trip's traveler.
    Dates must fall within the public trip's from_date/to_date.
    """
    def __init__(
        self,
        *,
        host_user_id: builtins.int | None = ...,
        from_date: builtins.str | None = ...,
        to_date: builtins.str | None = ...,
        text: builtins.str | None = ...,
        public_trip_id: builtins.int | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["_public_trip_id", b"_public_trip_id", "public_trip_id", b"public_trip_id"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["_public_trip_id", b"_public_trip_id", "from_date", b"from_date", "host_user_id", b"host_user_id", "public_trip_id", b"public_trip_id", "text", b"text", "to_date", b"to_date"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType__public_trip_id: typing_extensions.TypeAlias = typing.Literal["public_trip_id"]
    _WhichOneofArgType__public_trip_id: typing_extensions.TypeAlias = typing.Literal["_public_trip_id", b"_public_trip_id"]
    def WhichOneof(self, oneof_group: _WhichOneofArgType__public_trip_id) -> _WhichOneofReturnType__public_trip_id | None: ...

Global___CreateHostRequestReq: typing_extensions.TypeAlias = CreateHostRequestReq

@typing.final
class HostRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REQUEST_ID_FIELD_NUMBER: builtins.int
    SURFER_USER_ID_FIELD_NUMBER: builtins.int
    HOST_USER_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    FROM_DATE_FIELD_NUMBER: builtins.int
    TO_DATE_FIELD_NUMBER: builtins.int
    LAST_SEEN_MESSAGE_ID_FIELD_NUMBER: builtins.int
    LATEST_MESSAGE_FIELD_NUMBER: builtins.int
    HOSTING_CITY_FIELD_NUMBER: builtins.int
    HOSTING_LAT_FIELD_NUMBER: builtins.int
    HOSTING_LNG_FIELD_NUMBER: builtins.int
    HOSTING_RADIUS_FIELD_NUMBER: builtins.int
    NEED_HOST_REQUEST_FEEDBACK_FIELD_NUMBER: builtins.int
    IS_ARCHIVED_FIELD_NUMBER: builtins.int
    PUBLIC_TRIP_ID_FIELD_NUMBER: builtins.int
    host_request_id: builtins.int
    surfer_user_id: builtins.int
    host_user_id: builtins.int
    status: conversations_pb2.HostRequestStatus.ValueType
    from_date: builtins.str
    """dates as "yyyy-mm-dd", these are associated with a timezone, but that's not yet returned here TODO?"""
    to_date: builtins.str
    last_seen_message_id: builtins.int
    hosting_city: builtins.str
    hosting_lat: builtins.float
    hosting_lng: builtins.float
    hosting_radius: builtins.float
    need_host_request_feedback: builtins.bool
    is_archived: builtins.bool
    public_trip_id: builtins.int
    """If set, this host request was created in response to a public trip"""
    @property
    def created(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def latest_message(self) -> conversations_pb2.Message: ...
    def __init__(
        self,
        *,
        host_request_id: builtins.int | None = ...,
        surfer_user_id: builtins.int | None = ...,
        host_user_id: builtins.int | None = ...,
        status: conversations_pb2.HostRequestStatus.ValueType | None = ...,
        created: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        from_date: builtins.str | None = ...,
        to_date: builtins.str | None = ...,
        last_seen_message_id: builtins.int | None = ...,
        latest_message: conversations_pb2.Message | None = ...,
        hosting_city: builtins.str | None = ...,
        hosting_lat: builtins.float | None = ...,
        hosting_lng: builtins.float | None = ...,
        hosting_radius: builtins.float | None = ...,
        need_host_request_feedback: builtins.bool | None = ...,
        is_archived: builtins.bool | None = ...,
        public_trip_id: builtins.int | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["_public_trip_id", b"_public_trip_id", "created", b"created", "latest_message", b"latest_message", "public_trip_id", b"public_trip_id"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["_public_trip_id", b"_public_trip_id", "created", b"created", "from_date", b"from_date", "host_request_id", b"host_request_id", "host_user_id", b"host_user_id", "hosting_city", b"hosting_city", "hosting_lat", b"hosting_lat", "hosting_lng", b"hosting_lng", "hosting_radius", b"hosting_radius", "is_archived", b"is_archived", "last_seen_message_id", b"last_seen_message_id", "latest_message", b"latest_message", "need_host_request_feedback", b"need_host_request_feedback", "public_trip_id", b"public_trip_id", "status", b"status", "surfer_user_id", b"surfer_user_id", "to_date", b"to_date"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType__public_trip_id: typing_extensions.TypeAlias = typing.Literal["public_trip_id"]
    _WhichOneofArgType__public_trip_id: typing_extensions.TypeAlias = typing.Literal["_public_trip_id", b"_public_trip_id"]
    def WhichOneof(self, oneof_group: _WhichOneofArgType__public_trip_id) -> _WhichOneofReturnType__public_trip_id | None: ...

Global___HostRequest: typing_extensions.TypeAlias = HostRequest

@typing.final
class GetHostRequestReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REQUEST_ID_FIELD_NUMBER: builtins.int
    host_request_id: builtins.int
    def __init__(
        self,
        *,
        host_request_id: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["host_request_id", b"host_request_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetHostRequestReq: typing_extensions.TypeAlias = GetHostRequestReq

@typing.final
class CreateHostRequestRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REQUEST_ID_FIELD_NUMBER: builtins.int
    host_request_id: builtins.int
    def __init__(
        self,
        *,
        host_request_id: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["host_request_id", b"host_request_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___CreateHostRequestRes: typing_extensions.TypeAlias = CreateHostRequestRes

@typing.final
class RespondHostRequestReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REQUEST_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    host_request_id: builtins.int
    status: conversations_pb2.HostRequestStatus.ValueType
    text: builtins.str
    def __init__(
        self,
        *,
        host_request_id: builtins.int | None = ...,
        status: conversations_pb2.HostRequestStatus.ValueType | None = ...,
        text: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["host_request_id", b"host_request_id", "status", b"status", "text", b"text"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___RespondHostRequestReq: typing_extensions.TypeAlias = RespondHostRequestReq

@typing.final
class SetHostRequestArchiveStatusReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REQUEST_ID_FIELD_NUMBER: builtins.int
    IS_ARCHIVED_FIELD_NUMBER: builtins.int
    host_request_id: builtins.int
    is_archived: builtins.bool
    def __init__(
        self,
        *,
        host_request_id: builtins.int | None = ...,
        is_archived: builtins.bool | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["host_request_id", b"host_request_id", "is_archived", b"is_archived"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SetHostRequestArchiveStatusReq: typing_extensions.TypeAlias = SetHostRequestArchiveStatusReq

@typing.final
class SetHostRequestArchiveStatusRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REQUEST_ID_FIELD_NUMBER: builtins.int
    IS_ARCHIVED_FIELD_NUMBER: builtins.int
    host_request_id: builtins.int
    is_archived: builtins.bool
    def __init__(
        self,
        *,
        host_request_id: builtins.int | None = ...,
        is_archived: builtins.bool | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["host_request_id", b"host_request_id", "is_archived", b"is_archived"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SetHostRequestArchiveStatusRes: typing_extensions.TypeAlias = SetHostRequestArchiveStatusRes

@typing.final
class ListHostRequestsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUMBER_FIELD_NUMBER: builtins.int
    ONLY_ACTIVE_FIELD_NUMBER: builtins.int
    ONLY_SENT_FIELD_NUMBER: builtins.int
    ONLY_RECEIVED_FIELD_NUMBER: builtins.int
    ONLY_ARCHIVED_FIELD_NUMBER: builtins.int
    STATUS_IN_FIELD_NUMBER: builtins.int
    SORT_BY_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    number: builtins.int
    only_active: builtins.bool
    """Whether to only show pending, accepted and
    confirmed requests which haven't passed the
    end date.
    """
    only_sent: builtins.bool
    only_received: builtins.bool
    only_archived: builtins.bool
    sort_by: Global___HostRequestSortBy.ValueType
    page_token: builtins.str
    @property
    def status_in(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[conversations_pb2.HostRequestStatus.ValueType]:
        """If non-empty, only return requests with one of these statuses."""

    def __init__(
        self,
        *,
        number: builtins.int | None = ...,
        only_active: builtins.bool | None = ...,
        only_sent: builtins.bool | None = ...,
        only_received: builtins.bool | None = ...,
        only_archived: builtins.bool | None = ...,
        status_in: collections.abc.Iterable[conversations_pb2.HostRequestStatus.ValueType] | None = ...,
        sort_by: Global___HostRequestSortBy.ValueType | None = ...,
        page_token: builtins.str | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["_only_archived", b"_only_archived", "only_archived", b"only_archived"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["_only_archived", b"_only_archived", "number", b"number", "only_active", b"only_active", "only_archived", b"only_archived", "only_received", b"only_received", "only_sent", b"only_sent", "page_token", b"page_token", "sort_by", b"sort_by", "status_in", b"status_in"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType__only_archived: typing_extensions.TypeAlias = typing.Literal["only_archived"]
    _WhichOneofArgType__only_archived: typing_extensions.TypeAlias = typing.Literal["_only_archived", b"_only_archived"]
    def WhichOneof(self, oneof_group: _WhichOneofArgType__only_archived) -> _WhichOneofReturnType__only_archived | None: ...

Global___ListHostRequestsReq: typing_extensions.TypeAlias = ListHostRequestsReq

@typing.final
class ListHostRequestsRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REQUESTS_FIELD_NUMBER: builtins.int
    NO_MORE_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    no_more: builtins.bool
    next_page_token: builtins.str
    @property
    def host_requests(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___HostRequest]: ...
    def __init__(
        self,
        *,
        host_requests: collections.abc.Iterable[Global___HostRequest] | None = ...,
        no_more: builtins.bool | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["host_requests", b"host_requests", "next_page_token", b"next_page_token", "no_more", b"no_more"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListHostRequestsRes: typing_extensions.TypeAlias = ListHostRequestsRes

@typing.final
class GetHostRequestMessagesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REQUEST_ID_FIELD_NUMBER: builtins.int
    LAST_MESSAGE_ID_FIELD_NUMBER: builtins.int
    NUMBER_FIELD_NUMBER: builtins.int
    host_request_id: builtins.int
    last_message_id: builtins.int
    number: builtins.int
    def __init__(
        self,
        *,
        host_request_id: builtins.int | None = ...,
        last_message_id: builtins.int | None = ...,
        number: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["host_request_id", b"host_request_id", "last_message_id", b"last_message_id", "number", b"number"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetHostRequestMessagesReq: typing_extensions.TypeAlias = GetHostRequestMessagesReq

@typing.final
class GetHostRequestMessagesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGES_FIELD_NUMBER: builtins.int
    LAST_MESSAGE_ID_FIELD_NUMBER: builtins.int
    NO_MORE_FIELD_NUMBER: builtins.int
    last_message_id: builtins.int
    no_more: builtins.bool
    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[conversations_pb2.Message]: ...
    def __init__(
        self,
        *,
        messages: collections.abc.Iterable[conversations_pb2.Message] | None = ...,
        last_message_id: builtins.int | None = ...,
        no_more: builtins.bool | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["last_message_id", b"last_message_id", "messages", b"messages", "no_more", b"no_more"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetHostRequestMessagesRes: typing_extensions.TypeAlias = GetHostRequestMessagesRes

@typing.final
class SendHostRequestMessageReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REQUEST_ID_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    host_request_id: builtins.int
    text: builtins.str
    def __init__(
        self,
        *,
        host_request_id: builtins.int | None = ...,
        text: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["host_request_id", b"host_request_id", "text", b"text"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SendHostRequestMessageReq: typing_extensions.TypeAlias = SendHostRequestMessageReq

@typing.final
class GetHostRequestUpdatesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NEWEST_MESSAGE_ID_FIELD_NUMBER: builtins.int
    NUMBER_FIELD_NUMBER: builtins.int
    ONLY_SENT_FIELD_NUMBER: builtins.int
    ONLY_RECEIVED_FIELD_NUMBER: builtins.int
    newest_message_id: builtins.int
    number: builtins.int
    only_sent: builtins.bool
    only_received: builtins.bool
    def __init__(
        self,
        *,
        newest_message_id: builtins.int | None = ...,
        number: builtins.int | None = ...,
        only_sent: builtins.bool | None = ...,
        only_received: builtins.bool | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["newest_message_id", b"newest_message_id", "number", b"number", "only_received", b"only_received", "only_sent", b"only_sent"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetHostRequestUpdatesReq: typing_extensions.TypeAlias = GetHostRequestUpdatesReq

@typing.final
class HostRequestUpdate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REQUEST_ID_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    host_request_id: builtins.int
    status: conversations_pb2.HostRequestStatus.ValueType
    """the current status of the host request, regardless of this update"""
    @property
    def message(self) -> conversations_pb2.Message: ...
    def __init__(
        self,
        *,
        host_request_id: builtins.int | None = ...,
        message: conversations_pb2.Message | None = ...,
        status: conversations_pb2.HostRequestStatus.ValueType | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["message", b"message"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["host_request_id", b"host_request_id", "message", b"message", "status", b"status"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___HostRequestUpdate: typing_extensions.TypeAlias = HostRequestUpdate

@typing.final
class GetHostRequestUpdatesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPDATES_FIELD_NUMBER: builtins.int
    NO_MORE_FIELD_NUMBER: builtins.int
    no_more: builtins.bool
    @property
    def updates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___HostRequestUpdate]: ...
    def __init__(
        self,
        *,
        updates: collections.abc.Iterable[Global___HostRequestUpdate] | None = ...,
        no_more: builtins.bool | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["no_more", b"no_more", "updates", b"updates"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetHostRequestUpdatesRes: typing_extensions.TypeAlias = GetHostRequestUpdatesRes

@typing.final
class MarkLastSeenHostRequestReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REQUEST_ID_FIELD_NUMBER: builtins.int
    LAST_SEEN_MESSAGE_ID_FIELD_NUMBER: builtins.int
    host_request_id: builtins.int
    last_seen_message_id: builtins.int
    def __init__(
        self,
        *,
        host_request_id: builtins.int | None = ...,
        last_seen_message_id: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["host_request_id", b"host_request_id", "last_seen_message_id", b"last_seen_message_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___MarkLastSeenHostRequestReq: typing_extensions.TypeAlias = MarkLastSeenHostRequestReq

@typing.final
class GetResponseRateReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.int
    def __init__(
        self,
        *,
        user_id: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["user_id", b"user_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetResponseRateReq: typing_extensions.TypeAlias = GetResponseRateReq

@typing.final
class ResponseRateInsufficientData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___ResponseRateInsufficientData: typing_extensions.TypeAlias = ResponseRateInsufficientData

@typing.final
class ResponseRateLow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___ResponseRateLow: typing_extensions.TypeAlias = ResponseRateLow

@typing.final
class ResponseRateSome(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESPONSE_TIME_P33_FIELD_NUMBER: builtins.int
    @property
    def response_time_p33(self) -> google.protobuf.duration_pb2.Duration:
        """the 33rd percentile response time"""

    def __init__(
        self,
        *,
        response_time_p33: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["response_time_p33", b"response_time_p33"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["response_time_p33", b"response_time_p33"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ResponseRateSome: typing_extensions.TypeAlias = ResponseRateSome

@typing.final
class ResponseRateMost(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESPONSE_TIME_P33_FIELD_NUMBER: builtins.int
    RESPONSE_TIME_P66_FIELD_NUMBER: builtins.int
    @property
    def response_time_p33(self) -> google.protobuf.duration_pb2.Duration:
        """the 33rd percentile response time"""

    @property
    def response_time_p66(self) -> google.protobuf.duration_pb2.Duration:
        """the 66th percentile response time"""

    def __init__(
        self,
        *,
        response_time_p33: google.protobuf.duration_pb2.Duration | None = ...,
        response_time_p66: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["response_time_p33", b"response_time_p33", "response_time_p66", b"response_time_p66"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["response_time_p33", b"response_time_p33", "response_time_p66", b"response_time_p66"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ResponseRateMost: typing_extensions.TypeAlias = ResponseRateMost

@typing.final
class ResponseRateAlmostAll(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESPONSE_TIME_P33_FIELD_NUMBER: builtins.int
    RESPONSE_TIME_P66_FIELD_NUMBER: builtins.int
    @property
    def response_time_p33(self) -> google.protobuf.duration_pb2.Duration:
        """the 33rd percentile response time"""

    @property
    def response_time_p66(self) -> google.protobuf.duration_pb2.Duration:
        """the 66th percentile response time"""

    def __init__(
        self,
        *,
        response_time_p33: google.protobuf.duration_pb2.Duration | None = ...,
        response_time_p66: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["response_time_p33", b"response_time_p33", "response_time_p66", b"response_time_p66"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["response_time_p33", b"response_time_p33", "response_time_p66", b"response_time_p66"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ResponseRateAlmostAll: typing_extensions.TypeAlias = ResponseRateAlmostAll

@typing.final
class GetResponseRateRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSUFFICIENT_DATA_FIELD_NUMBER: builtins.int
    LOW_FIELD_NUMBER: builtins.int
    SOME_FIELD_NUMBER: builtins.int
    MOST_FIELD_NUMBER: builtins.int
    ALMOST_ALL_FIELD_NUMBER: builtins.int
    @property
    def insufficient_data(self) -> Global___ResponseRateInsufficientData:
        """received <3 requests"""

    @property
    def low(self) -> Global___ResponseRateLow:
        """response rate <= 33%"""

    @property
    def some(self) -> Global___ResponseRateSome:
        """response rate > 33%, but <= 66%"""

    @property
    def most(self) -> Global___ResponseRateMost:
        """response rate > 66%, but <= 90%"""

    @property
    def almost_all(self) -> Global___ResponseRateAlmostAll:
        """response rate > 90%"""

    def __init__(
        self,
        *,
        insufficient_data: Global___ResponseRateInsufficientData | None = ...,
        low: Global___ResponseRateLow | None = ...,
        some: Global___ResponseRateSome | None = ...,
        most: Global___ResponseRateMost | None = ...,
        almost_all: Global___ResponseRateAlmostAll | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["almost_all", b"almost_all", "insufficient_data", b"insufficient_data", "low", b"low", "most", b"most", "response_rate", b"response_rate", "some", b"some"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["almost_all", b"almost_all", "insufficient_data", b"insufficient_data", "low", b"low", "most", b"most", "response_rate", b"response_rate", "some", b"some"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType_response_rate: typing_extensions.TypeAlias = typing.Literal["insufficient_data", "low", "some", "most", "almost_all"]
    _WhichOneofArgType_response_rate: typing_extensions.TypeAlias = typing.Literal["response_rate", b"response_rate"]
    def WhichOneof(self, oneof_group: _WhichOneofArgType_response_rate) -> _WhichOneofReturnType_response_rate | None: ...

Global___GetResponseRateRes: typing_extensions.TypeAlias = GetResponseRateRes

@typing.final
class SendHostRequestFeedbackReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REQUEST_ID_FIELD_NUMBER: builtins.int
    HOST_REQUEST_QUALITY_FIELD_NUMBER: builtins.int
    DECLINE_REASON_FIELD_NUMBER: builtins.int
    host_request_id: builtins.int
    host_request_quality: Global___HostRequestQuality.ValueType
    decline_reason: builtins.str
    def __init__(
        self,
        *,
        host_request_id: builtins.int | None = ...,
        host_request_quality: Global___HostRequestQuality.ValueType | None = ...,
        decline_reason: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["decline_reason", b"decline_reason", "host_request_id", b"host_request_id", "host_request_quality", b"host_request_quality"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SendHostRequestFeedbackReq: typing_extensions.TypeAlias = SendHostRequestFeedbackReq



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import communities_pb2
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class CommunitiesStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    GetCommunity: grpc.UnaryUnaryMultiCallable[communities_pb2.GetCommunityReq, communities_pb2.Community]
    """Get info about a Community"""
    ListCommunities: grpc.UnaryUnaryMultiCallable[communities_pb2.ListCommunitiesReq, communities_pb2.ListCommunitiesRes]
    """Gets a paginated list of sub-communities associated with a community"""
    ListGroups: grpc.UnaryUnaryMultiCallable[communities_pb2.ListGroupsReq, communities_pb2.ListGroupsRes]
    """Gets a paginated list of groups associated with a community"""
    ListAdmins: grpc.UnaryUnaryMultiCallable[communities_pb2.ListAdminsReq, communities_pb2.ListAdminsRes]
    """Gets a paginated list of community admins only"""
    AddAdmin: grpc.UnaryUnaryMultiCallable[communities_pb2.AddAdminReq, google.protobuf.empty_pb2.Empty]
    """Makes a user a community builder

    Raises: FAILED_PRECONDITION if
      1. the active user cannot moderate the community node
      2. the specified user is already an admin of the community
      3. the specified user is not a member of the community
    """
    RemoveAdmin: grpc.UnaryUnaryMultiCallable[communities_pb2.RemoveAdminReq, google.protobuf.empty_pb2.Empty]
    """Removes user as community builder

    Raises: FAILED_PRECONDITION if
      1. the active user cannot moderate the community node
      2. the specified user is not an admin of the community
    """
    ListMembers: grpc.UnaryUnaryMultiCallable[communities_pb2.ListMembersReq, communities_pb2.ListMembersRes]
    """Gets a paginated list of community members, including admins"""
    ListNearbyUsers: grpc.UnaryUnaryMultiCallable[communities_pb2.ListNearbyUsersReq, communities_pb2.ListNearbyUsersRes]
    """Gets a paginated list of users who live within the polygon of the community"""
    ListPlaces: grpc.UnaryUnaryMultiCallable[communities_pb2.ListPlacesReq, communities_pb2.ListPlacesRes]
    """Returns a paginated list of places associated with a community"""
    ListGuides: grpc.UnaryUnaryMultiCallable[communities_pb2.ListGuidesReq, communities_pb2.ListGuidesRes]
    """Returns a paginated list of guides associated with a community"""
    ListEvents: grpc.UnaryUnaryMultiCallable[communities_pb2.ListEventsReq, communities_pb2.ListEventsRes]
    """Returns a paginated list of events associated with a community"""
    ListDiscussions: grpc.UnaryUnaryMultiCallable[communities_pb2.ListDiscussionsReq, communities_pb2.ListDiscussionsRes]
    """Returns a paginated list of discussions associated with a community"""
    JoinCommunity: grpc.UnaryUnaryMultiCallable[communities_pb2.JoinCommunityReq, google.protobuf.empty_pb2.Empty]
    """Join a community you're not a part of

    Raises: FAILED_PRECONDITION if the user is already part of the community
    """
    LeaveCommunity: grpc.UnaryUnaryMultiCallable[communities_pb2.LeaveCommunityReq, google.protobuf.empty_pb2.Empty]
    """Leave a community that you're not inside.
    You cannot leave a community that you live inside.

    Raises: FAILED_PRECONDITION if the user is not part of the community or if their location is within the community
    """
    ListUserCommunities: grpc.UnaryUnaryMultiCallable[communities_pb2.ListUserCommunitiesReq, communities_pb2.ListUserCommunitiesRes]
    """Gets a list of communities a member belongs to"""
    SearchCommunities: grpc.UnaryUnaryMultiCallable[communities_pb2.SearchCommunitiesReq, communities_pb2.SearchCommunitiesRes]
    """Gets a list of communities in accordance to search request"""
    ListAllCommunities: grpc.UnaryUnaryMultiCallable[communities_pb2.ListAllCommunitiesReq, communities_pb2.ListAllCommunitiesRes]
    """Gets a list of all communities, ordered hierarchically"""
    ListRecentCommunities: grpc.UnaryUnaryMultiCallable[communities_pb2.ListRecentCommunitiesReq, communities_pb2.ListRecentCommunitiesRes]
    """Gets the most recently created communities across the whole tree, ordered newest-first"""

class CommunitiesServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetCommunity(
        self,
        request: communities_pb2.GetCommunityReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> communities_pb2.Community:
        """Get info about a Community"""

    @abc.abstractmethod
    def ListCommunities(
        self,
        request: communities_pb2.ListCommunitiesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> communities_pb2.ListCommunitiesRes:
        """Gets a paginated list of sub-communities associated with a community"""

    @abc.abstractmethod
    def ListGroups(
        self,
        request: communities_pb2.ListGroupsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> communities_pb2.ListGroupsRes:
        """Gets a paginated list of groups associated with a community"""

    @abc.abstractmethod
    def ListAdmins(
        self,
        request: communities_pb2.ListAdminsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> communities_pb2.ListAdminsRes:
        """Gets a paginated list of community admins only"""

    @abc.abstractmethod
    def AddAdmin(
        self,
        request: communities_pb2.AddAdminReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Makes a user a community builder

        Raises: FAILED_PRECONDITION if
          1. the active user cannot moderate the community node
          2. the specified user is already an admin of the community
          3. the specified user is not a member of the community
        """

    @abc.abstractmethod
    def RemoveAdmin(
        self,
        request: communities_pb2.RemoveAdminReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Removes user as community builder

        Raises: FAILED_PRECONDITION if
          1. the active user cannot moderate the community node
          2. the specified user is not an admin of the community
        """

    @abc.abstractmethod
    def ListMembers(
        self,
        request: communities_pb2.ListMembersReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> communities_pb2.ListMembersRes:
        """Gets a paginated list of community members, including admins"""

    @abc.abstractmethod
    def ListNearbyUsers(
        self,
        request: communities_pb2.ListNearbyUsersReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> communities_pb2.ListNearbyUsersRes:
        """Gets a paginated list of users who live within the polygon of the community"""

    @abc.abstractmethod
    def ListPlaces(
        self,
        request: communities_pb2.ListPlacesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> communities_pb2.ListPlacesRes:
        """Returns a paginated list of places associated with a community"""

    @abc.abstractmethod
    def ListGuides(
        self,
        request: communities_pb2.ListGuidesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> communities_pb2.ListGuidesRes:
        """Returns a paginated list of guides associated with a community"""

    @abc.abstractmethod
    def ListEvents(
        self,
        request: communities_pb2.ListEventsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> communities_pb2.ListEventsRes:
        """Returns a paginated list of events associated with a community"""

    @abc.abstractmethod
    def ListDiscussions(
        self,
        request: communities_pb2.ListDiscussionsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> communities_pb2.ListDiscussionsRes:
        """Returns a paginated list of discussions associated with a community"""

    @abc.abstractmethod
    def JoinCommunity(
        self,
        request: communities_pb2.JoinCommunityReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Join a community you're not a part of

        Raises: FAILED_PRECONDITION if the user is already part of the community
        """

    @abc.abstractmethod
    def LeaveCommunity(
        self,
        request: communities_pb2.LeaveCommunityReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Leave a community that you're not inside.
        You cannot leave a community that you live inside.

        Raises: FAILED_PRECONDITION if the user is not part of the community or if their location is within the community
        """

    @abc.abstractmethod
    def ListUserCommunities(
        self,
        request: communities_pb2.ListUserCommunitiesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> communities_pb2.ListUserCommunitiesRes:
        """Gets a list of communities a member belongs to"""

    @abc.abstractmethod
    def SearchCommunities(
        self,
        request: communities_pb2.SearchCommunitiesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> communities_pb2.SearchCommunitiesRes:
        """Gets a list of communities in accordance to search request"""

    @abc.abstractmethod
    def ListAllCommunities(
        self,
        request: communities_pb2.ListAllCommunitiesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> communities_pb2.ListAllCommunitiesRes:
        """Gets a list of all communities, ordered hierarchically"""

    @abc.abstractmethod
    def ListRecentCommunities(
        self,
        request: communities_pb2.ListRecentCommunitiesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> communities_pb2.ListRecentCommunitiesRes:
        """Gets the most recently created communities across the whole tree, ordered newest-first"""

def add_CommunitiesServicer_to_server(servicer: CommunitiesServicer, server: grpc.Server) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import admin_pb2 as admin__pb2
from . import api_pb2 as api__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class AdminStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetUserDetails = channel.unary_unary(
                '/org.couchers.admin.Admin/GetUserDetails',
                request_serializer=admin__pb2.GetUserDetailsReq.SerializeToString,
                response_deserializer=admin__pb2.UserDetails.FromString,
                )
        self.GetUser = channel.unary_unary(
                '/org.couchers.admin.Admin/GetUser',
                request_serializer=admin__pb2.GetUserReq.SerializeToString,
                response_deserializer=api__pb2.User.FromString,
                )
        self.SearchUsers = channel.unary_unary(
                '/org.couchers.admin.Admin/SearchUsers',
                request_serializer=admin__pb2.SearchUsersReq.SerializeToString,
                response_deserializer=admin__pb2.SearchUsersRes.FromString,
                )
        self.ChangeUserGender = channel.unary_unary(
                '/org.couchers.admin.Admin/ChangeUserGender',
                request_serializer=admin__pb2.ChangeUserGenderReq.SerializeToString,
                response_deserializer=admin__pb2.UserDetails.FromString,
                )
        self.ChangeUserBirthdate = channel.unary_unary(
                '/org.couchers.admin.Admin/ChangeUserBirthdate',
                request_serializer=admin__pb2.ChangeUserBirthdateReq.SerializeToString,
                response_deserializer=admin__pb2.UserDetails.FromString,
                )
        self.AddBadge = channel.unary_unary(
                '/org.couchers.admin.Admin/AddBadge',
                request_serializer=admin__pb2.AddBadgeReq.SerializeToString,
                response_deserializer=admin__pb2.UserDetails.FromString,
                )
        self.RemoveBadge = channel.unary_unary(
                '/org.couchers.admin.Admin/RemoveBadge',
                request_serializer=admin__pb2.RemoveBadgeReq.SerializeToString,
                response_deserializer=admin__pb2.UserDetails.FromString,
                )
        self.SetPassportSexGenderException = channel.unary_unary(
                '/org.couchers.admin.Admin/SetPassportSexGenderException',
                request_serializer=admin__pb2.SetPassportSexGenderExceptionReq.SerializeToString,
                response_deserializer=admin__pb2.UserDetails.FromString,
                )
        self.BanUser = channel.unary_unary(
                '/org.couchers.admin.Admin/BanUser',
                request_serializer=admin__pb2.BanUserReq.SerializeToString,
                response_deserializer=admin__pb2.UserDetails.FromString,
                )
        self.UnbanUser = channel.unary_unary(
                '/org.couchers.admin.Admin/UnbanUser',
                request_serializer=admin__pb2.UnbanUserReq.SerializeToString,
                response_deserializer=admin__pb2.UserDetails.FromString,
                )
        self.ShadowUser = channel.unary_unary(
                '/org.couchers.admin.Admin/ShadowUser',
                request_serializer=admin__pb2.ShadowUserReq.SerializeToString,
                response_deserializer=admin__pb2.UserDetails.FromString,
                )
        self.UnshadowUser = channel.unary_unary(
                '/org.couchers.admin.Admin/UnshadowUser',
                request_serializer=admin__pb2.UnshadowUserReq.SerializeToString,
                response_deserializer=admin__pb2.UserDetails.FromString,
                )
        self.AddAdminNote = channel.unary_unary(
                '/org.couchers.admin.Admin/AddAdminNote',
                request_serializer=admin__pb2.AddAdminNoteReq.SerializeToString,
                response_deserializer=admin__pb2.UserDetails.FromString,
                )
        self.GetContentReport = channel.unary_unary(
                '/org.couchers.admin.Admin/GetContentReport',
                request_serializer=admin__pb2.GetContentReportReq.SerializeToString,
                response_deserializer=admin__pb2.GetContentReportRes.FromString,
                )
        self.GetContentReportsForAuthor = channel.unary_unary(
                '/org.couchers.admin.Admin/GetContentReportsForAuthor',
                request_serializer=admin__pb2.GetContentReportsForAuthorReq.SerializeToString,
                response_deserializer=admin__pb2.GetContentReportsForAuthorRes.FromString,
                )
        self.SendModNote = channel.unary_unary(
                '/org.couchers.admin.Admin/SendModNote',
                request_serializer=admin__pb2.SendModNoteReq.SerializeToString,
                response_deserializer=admin__pb2.UserDetails.FromString,
                )
        self.MarkUserNeedsLocationUpdate = channel.unary_unary(
                '/org.couchers.admin.Admin/MarkUserNeedsLocationUpdate',
                request_serializer=admin__pb2.MarkUserNeedsLocationUpdateReq.SerializeToString,
                response_deserializer=admin__pb2.UserDetails.FromString,
                )
        self.DeleteUser = channel.unary_unary(
                '/org.couchers.admin.Admin/DeleteUser',
                request_serializer=admin__pb2.DeleteUserReq.SerializeToString,
                response_deserializer=admin__pb2.UserDetails.FromString,
                )
        self.RecoverDeletedUser = channel.unary_unary(
                '/org.couchers.admin.Admin/RecoverDeletedUser',
                request_serializer=admin__pb2.RecoverDeletedUserReq.SerializeToString,
                response_deserializer=admin__pb2.UserDetails.FromString,
                )
        self.CreateApiKey = channel.unary_unary(
                '/org.couchers.admin.Admin/CreateApiKey',
                request_serializer=admin__pb2.CreateApiKeyReq.SerializeToString,
                response_deserializer=admin__pb2.CreateApiKeyRes.FromString,
                )
        self.GetChats = channel.unary_unary(
                '/org.couchers.admin.Admin/GetChats',
                request_serializer=admin__pb2.GetChatsReq.SerializeToString,
                response_deserializer=admin__pb2.GetChatsRes.FromString,
                )
        self.DeleteEvent = channel.unary_unary(
                '/org.couchers.admin.Admin/DeleteEvent',
                request_serializer=admin__pb2.DeleteEventReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListUserIds = channel.unary_unary(
                '/org.couchers.admin.Admin/ListUserIds',
                request_serializer=admin__pb2.ListUserIdsReq.SerializeToString,
                response_deserializer=admin__pb2.ListUserIdsRes.FromString,
                )
        self.EditReferenceText = channel.unary_unary(
                '/org.couchers.admin.Admin/EditReferenceText',
                request_serializer=admin__pb2.EditReferenceTextReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteReference = channel.unary_unary(
                '/org.couchers.admin.Admin/DeleteReference',
                request_serializer=admin__pb2.DeleteReferenceReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetUserReferences = channel.unary_unary(
                '/org.couchers.admin.Admin/GetUserReferences',
                request_serializer=admin__pb2.GetUserReferencesReq.SerializeToString,
                response_deserializer=admin__pb2.GetUserReferencesRes.FromString,
                )
        self.GetFriendRequests = channel.unary_unary(
                '/org.couchers.admin.Admin/GetFriendRequests',
                request_serializer=admin__pb2.GetFriendRequestsReq.SerializeToString,
                response_deserializer=admin__pb2.GetFriendRequestsRes.FromString,
                )
        self.GetNonvisibleUserAccessLog = channel.unary_unary(
                '/org.couchers.admin.Admin/GetNonvisibleUserAccessLog',
                request_serializer=admin__pb2.GetNonvisibleUserAccessLogReq.SerializeToString,
                response_deserializer=admin__pb2.GetNonvisibleUserAccessLogRes.FromString,
                )
        self.EditDiscussion = channel.unary_unary(
                '/org.couchers.admin.Admin/EditDiscussion',
                request_serializer=admin__pb2.EditDiscussionReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteDiscussion = channel.unary_unary(
                '/org.couchers.admin.Admin/DeleteDiscussion',
                request_serializer=admin__pb2.AdminDeleteDiscussionReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.EditReply = channel.unary_unary(
                '/org.couchers.admin.Admin/EditReply',
                request_serializer=admin__pb2.EditReplyReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.AddUsersToModerationUserList = channel.unary_unary(
                '/org.couchers.admin.Admin/AddUsersToModerationUserList',
                request_serializer=admin__pb2.AddUsersToModerationUserListReq.SerializeToString,
                response_deserializer=admin__pb2.AddUsersToModerationUserListRes.FromString,
                )
        self.RemoveUserFromModerationUserList = channel.unary_unary(
                '/org.couchers.admin.Admin/RemoveUserFromModerationUserList',
                request_serializer=admin__pb2.RemoveUserFromModerationUserListReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListModerationUserLists = channel.unary_unary(
                '/org.couchers.admin.Admin/ListModerationUserLists',
                request_serializer=admin__pb2.ListModerationUserListsReq.SerializeToString,
                response_deserializer=admin__pb2.ListModerationUserListsRes.FromString,
                )
        self.CreateAccountDeletionLink = channel.unary_unary(
                '/org.couchers.admin.Admin/CreateAccountDeletionLink',
                request_serializer=admin__pb2.CreateAccountDeletionLinkReq.SerializeToString,
                response_deserializer=admin__pb2.CreateAccountDeletionLinkRes.FromString,
                )
        self.AccessStats = channel.unary_unary(
                '/org.couchers.admin.Admin/AccessStats',
                request_serializer=admin__pb2.AccessStatsReq.SerializeToString,
                response_deserializer=admin__pb2.AccessStatsRes.FromString,
                )
        self.SetLastDonated = channel.unary_unary(
                '/org.couchers.admin.Admin/SetLastDonated',
                request_serializer=admin__pb2.SetLastDonatedReq.SerializeToString,
                response_deserializer=admin__pb2.UserDetails.FromString,
                )
        self.CreateAdminTag = channel.unary_unary(
                '/org.couchers.admin.Admin/CreateAdminTag',
                request_serializer=admin__pb2.CreateAdminTagReq.SerializeToString,
                response_deserializer=admin__pb2.AdminTagInfo.FromString,
                )
        self.ListAdminTags = channel.unary_unary(
                '/org.couchers.admin.Admin/ListAdminTags',
                request_serializer=admin__pb2.ListAdminTagsReq.SerializeToString,
                response_deserializer=admin__pb2.ListAdminTagsRes.FromString,
                )
        self.AddAdminTagToUser = channel.unary_unary(
                '/org.couchers.admin.Admin/AddAdminTagToUser',
                request_serializer=admin__pb2.AddAdminTagToUserReq.SerializeToString,
                response_deserializer=admin__pb2.UserDetails.FromString,
                )
        self.RemoveAdminTagFromUser = channel.unary_unary(
                '/org.couchers.admin.Admin/RemoveAdminTagFromUser',
                request_serializer=admin__pb2.RemoveAdminTagFromUserReq.SerializeToString,
                response_deserializer=admin__pb2.UserDetails.FromString,
                )
        self.SetModScore = channel.unary_unary(
                '/org.couchers.admin.Admin/SetModScore',
                request_serializer=admin__pb2.SetModScoreReq.SerializeToString,
                response_deserializer=admin__pb2.UserDetails.FromString,
                )
        self.ListAdminActions = channel.unary_unary(
                '/org.couchers.admin.Admin/ListAdminActions',
                request_serializer=admin__pb2.ListAdminActionsReq.SerializeToString,
                response_deserializer=admin__pb2.ListAdminActionsRes.FromString,
                )
        self.ListUserUploads = channel.unary_unary(
                '/org.couchers.admin.Admin/ListUserUploads',
                request_serializer=admin__pb2.ListUserUploadsReq.SerializeToString,
                response_deserializer=admin__pb2.ListUserUploadsRes.FromString,
                )
        self.CreateOTAPackage = channel.unary_unary(
                '/org.couchers.admin.Admin/CreateOTAPackage',
                request_serializer=admin__pb2.CreateOTAPackageReq.SerializeToString,
                response_deserializer=admin__pb2.OTAPackage.FromString,
                )
        self.ListOTAPackages = channel.unary_unary(
                '/org.couchers.admin.Admin/ListOTAPackages',
                request_serializer=admin__pb2.ListOTAPackagesReq.SerializeToString,
                response_deserializer=admin__pb2.ListOTAPackagesRes.FromString,
                )
        self.BanOTAPackage = channel.unary_unary(
                '/org.couchers.admin.Admin/BanOTAPackage',
                request_serializer=admin__pb2.BanOTAPackageReq.SerializeToString,
                response_deserializer=admin__pb2.OTAPackage.FromString,
                )


class AdminServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetUserDetails(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUser(self, request, context):
        """Get info about a particular user, ignores the fact that they may be banned/deleted
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SearchUsers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChangeUserGender(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChangeUserBirthdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddBadge(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveBadge(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetPassportSexGenderException(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BanUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnbanUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ShadowUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnshadowUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddAdminNote(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetContentReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetContentReportsForAuthor(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendModNote(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MarkUserNeedsLocationUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RecoverDeletedUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateApiKey(self, request, context):
        """Create an API key for a user. For security, we don't return the API key to the admin calling this API, rather
        it's sent to the user in an email
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetChats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteEvent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUserIds(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EditReferenceText(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteReference(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserReferences(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFriendRequests(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNonvisibleUserAccessLog(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EditDiscussion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDiscussion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EditReply(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddUsersToModerationUserList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveUserFromModerationUserList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListModerationUserLists(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAccountDeletionLink(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AccessStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetLastDonated(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAdminTag(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAdminTags(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddAdminTagToUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveAdminTagFromUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetModScore(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAdminActions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUserUploads(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOTAPackage(self, request, context):
        """Register a published Expo OTA bundle so the backend serves it to compatible native builds
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOTAPackages(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BanOTAPackage(self, request, context):
        """Ban a package so it's no longer served; a matching client falls back to the next-newest
        non-banned package (i.e. a rollback), or to no update if none remain. Irreversible — to undo
        an accidental ban, republish the bundle as a new package (rolling forward).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AdminServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetUserDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserDetails,
                    request_deserializer=admin__pb2.GetUserDetailsReq.FromString,
                    response_serializer=admin__pb2.UserDetails.SerializeToString,
            ),
            'GetUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUser,
                    request_deserializer=admin__pb2.GetUserReq.FromString,
                    response_serializer=api__pb2.User.SerializeToString,
            ),
            'SearchUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.SearchUsers,
                    request_deserializer=admin__pb2.SearchUsersReq.FromString,
                    response_serializer=admin__pb2.SearchUsersRes.SerializeToString,
            ),
            'ChangeUserGender': grpc.unary_unary_rpc_method_handler(
                    servicer.ChangeUserGender,
                    request_deserializer=admin__pb2.ChangeUserGenderReq.FromString,
                    response_serializer=admin__pb2.UserDetails.SerializeToString,
            ),
            'ChangeUserBirthdate': grpc.unary_unary_rpc_method_handler(
                    servicer.ChangeUserBirthdate,
                    request_deserializer=admin__pb2.ChangeUserBirthdateReq.FromString,
                    response_serializer=admin__pb2.UserDetails.SerializeToString,
            ),
            'AddBadge': grpc.unary_unary_rpc_method_handler(
                    servicer.AddBadge,
                    request_deserializer=admin__pb2.AddBadgeReq.FromString,
                    response_serializer=admin__pb2.UserDetails.SerializeToString,
            ),
            'RemoveBadge': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveBadge,
                    request_deserializer=admin__pb2.RemoveBadgeReq.FromString,
                    response_serializer=admin__pb2.UserDetails.SerializeToString,
            ),
            'SetPassportSexGenderException': grpc.unary_unary_rpc_method_handler(
                    servicer.SetPassportSexGenderException,
                    request_deserializer=admin__pb2.SetPassportSexGenderExceptionReq.FromString,
                    response_serializer=admin__pb2.UserDetails.SerializeToString,
            ),
            'BanUser': grpc.unary_unary_rpc_method_handler(
                    servicer.BanUser,
                    request_deserializer=admin__pb2.BanUserReq.FromString,
                    response_serializer=admin__pb2.UserDetails.SerializeToString,
            ),
            'UnbanUser': grpc.unary_unary_rpc_method_handler(
                    servicer.UnbanUser,
                    request_deserializer=admin__pb2.UnbanUserReq.FromString,
                    response_serializer=admin__pb2.UserDetails.SerializeToString,
            ),
            'ShadowUser': grpc.unary_unary_rpc_method_handler(
                    servicer.ShadowUser,
                    request_deserializer=admin__pb2.ShadowUserReq.FromString,
                    response_serializer=admin__pb2.UserDetails.SerializeToString,
            ),
            'UnshadowUser': grpc.unary_unary_rpc_method_handler(
                    servicer.UnshadowUser,
                    request_deserializer=admin__pb2.UnshadowUserReq.FromString,
                    response_serializer=admin__pb2.UserDetails.SerializeToString,
            ),
            'AddAdminNote': grpc.unary_unary_rpc_method_handler(
                    servicer.AddAdminNote,
                    request_deserializer=admin__pb2.AddAdminNoteReq.FromString,
                    response_serializer=admin__pb2.UserDetails.SerializeToString,
            ),
            'GetContentReport': grpc.unary_unary_rpc_method_handler(
                    servicer.GetContentReport,
                    request_deserializer=admin__pb2.GetContentReportReq.FromString,
                    response_serializer=admin__pb2.GetContentReportRes.SerializeToString,
            ),
            'GetContentReportsForAuthor': grpc.unary_unary_rpc_method_handler(
                    servicer.GetContentReportsForAuthor,
                    request_deserializer=admin__pb2.GetContentReportsForAuthorReq.FromString,
                    response_serializer=admin__pb2.GetContentReportsForAuthorRes.SerializeToString,
            ),
            'SendModNote': grpc.unary_unary_rpc_method_handler(
                    servicer.SendModNote,
                    request_deserializer=admin__pb2.SendModNoteReq.FromString,
                    response_serializer=admin__pb2.UserDetails.SerializeToString,
            ),
            'MarkUserNeedsLocationUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.MarkUserNeedsLocationUpdate,
                    request_deserializer=admin__pb2.MarkUserNeedsLocationUpdateReq.FromString,
                    response_serializer=admin__pb2.UserDetails.SerializeToString,
            ),
            'DeleteUser': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteUser,
                    request_deserializer=admin__pb2.DeleteUserReq.FromString,
                    response_serializer=admin__pb2.UserDetails.SerializeToString,
            ),
            'RecoverDeletedUser': grpc.unary_unary_rpc_method_handler(
                    servicer.RecoverDeletedUser,
                    request_deserializer=admin__pb2.RecoverDeletedUserReq.FromString,
                    response_serializer=admin__pb2.UserDetails.SerializeToString,
            ),
            'CreateApiKey': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateApiKey,
                    request_deserializer=admin__pb2.CreateApiKeyReq.FromString,
                    response_serializer=admin__pb2.CreateApiKeyRes.SerializeToString,
            ),
            'GetChats': grpc.unary_unary_rpc_method_handler(
                    servicer.GetChats,
                    request_deserializer=admin__pb2.GetChatsReq.FromString,
                    response_serializer=admin__pb2.GetChatsRes.SerializeToString,
            ),
            'DeleteEvent': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteEvent,
                    request_deserializer=admin__pb2.DeleteEventReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListUserIds': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUserIds,
                    request_deserializer=admin__pb2.ListUserIdsReq.FromString,
                    response_serializer=admin__pb2.ListUserIdsRes.SerializeToString,
            ),
            'EditReferenceText': grpc.unary_unary_rpc_method_handler(
                    servicer.EditReferenceText,
                    request_deserializer=admin__pb2.EditReferenceTextReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteReference': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteReference,
                    request_deserializer=admin__pb2.DeleteReferenceReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetUserReferences': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserReferences,
                    request_deserializer=admin__pb2.GetUserReferencesReq.FromString,
                    response_serializer=admin__pb2.GetUserReferencesRes.SerializeToString,
            ),
            'GetFriendRequests': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFriendRequests,
                    request_deserializer=admin__pb2.GetFriendRequestsReq.FromString,
                    response_serializer=admin__pb2.GetFriendRequestsRes.SerializeToString,
            ),
            'GetNonvisibleUserAccessLog': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNonvisibleUserAccessLog,
                    request_deserializer=admin__pb2.GetNonvisibleUserAccessLogReq.FromString,
                    response_serializer=admin__pb2.GetNonvisibleUserAccessLogRes.SerializeToString,
            ),
            'EditDiscussion': grpc.unary_unary_rpc_method_handler(
                    servicer.EditDiscussion,
                    request_deserializer=admin__pb2.EditDiscussionReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteDiscussion': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDiscussion,
                    request_deserializer=admin__pb2.AdminDeleteDiscussionReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'EditReply': grpc.unary_unary_rpc_method_handler(
                    servicer.EditReply,
                    request_deserializer=admin__pb2.EditReplyReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'AddUsersToModerationUserList': grpc.unary_unary_rpc_method_handler(
                    servicer.AddUsersToModerationUserList,
                    request_deserializer=admin__pb2.AddUsersToModerationUserListReq.FromString,
                    response_serializer=admin__pb2.AddUsersToModerationUserListRes.SerializeToString,
            ),
            'RemoveUserFromModerationUserList': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveUserFromModerationUserList,
                    request_deserializer=admin__pb2.RemoveUserFromModerationUserListReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListModerationUserLists': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModerationUserLists,
                    request_deserializer=admin__pb2.ListModerationUserListsReq.FromString,
                    response_serializer=admin__pb2.ListModerationUserListsRes.SerializeToString,
            ),
            'CreateAccountDeletionLink': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAccountDeletionLink,
                    request_deserializer=admin__pb2.CreateAccountDeletionLinkReq.FromString,
                    response_serializer=admin__pb2.CreateAccountDeletionLinkRes.SerializeToString,
            ),
            'AccessStats': grpc.unary_unary_rpc_method_handler(
                    servicer.AccessStats,
                    request_deserializer=admin__pb2.AccessStatsReq.FromString,
                    response_serializer=admin__pb2.AccessStatsRes.SerializeToString,
            ),
            'SetLastDonated': grpc.unary_unary_rpc_method_handler(
                    servicer.SetLastDonated,
                    request_deserializer=admin__pb2.SetLastDonatedReq.FromString,
                    response_serializer=admin__pb2.UserDetails.SerializeToString,
            ),
            'CreateAdminTag': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAdminTag,
                    request_deserializer=admin__pb2.CreateAdminTagReq.FromString,
                    response_serializer=admin__pb2.AdminTagInfo.SerializeToString,
            ),
            'ListAdminTags': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAdminTags,
                    request_deserializer=admin__pb2.ListAdminTagsReq.FromString,
                    response_serializer=admin__pb2.ListAdminTagsRes.SerializeToString,
            ),
            'AddAdminTagToUser': grpc.unary_unary_rpc_method_handler(
                    servicer.AddAdminTagToUser,
                    request_deserializer=admin__pb2.AddAdminTagToUserReq.FromString,
                    response_serializer=admin__pb2.UserDetails.SerializeToString,
            ),
            'RemoveAdminTagFromUser': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveAdminTagFromUser,
                    request_deserializer=admin__pb2.RemoveAdminTagFromUserReq.FromString,
                    response_serializer=admin__pb2.UserDetails.SerializeToString,
            ),
            'SetModScore': grpc.unary_unary_rpc_method_handler(
                    servicer.SetModScore,
                    request_deserializer=admin__pb2.SetModScoreReq.FromString,
                    response_serializer=admin__pb2.UserDetails.SerializeToString,
            ),
            'ListAdminActions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAdminActions,
                    request_deserializer=admin__pb2.ListAdminActionsReq.FromString,
                    response_serializer=admin__pb2.ListAdminActionsRes.SerializeToString,
            ),
            'ListUserUploads': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUserUploads,
                    request_deserializer=admin__pb2.ListUserUploadsReq.FromString,
                    response_serializer=admin__pb2.ListUserUploadsRes.SerializeToString,
            ),
            'CreateOTAPackage': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOTAPackage,
                    request_deserializer=admin__pb2.CreateOTAPackageReq.FromString,
                    response_serializer=admin__pb2.OTAPackage.SerializeToString,
            ),
            'ListOTAPackages': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOTAPackages,
                    request_deserializer=admin__pb2.ListOTAPackagesReq.FromString,
                    response_serializer=admin__pb2.ListOTAPackagesRes.SerializeToString,
            ),
            'BanOTAPackage': grpc.unary_unary_rpc_method_handler(
                    servicer.BanOTAPackage,
                    request_deserializer=admin__pb2.BanOTAPackageReq.FromString,
                    response_serializer=admin__pb2.OTAPackage.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.admin.Admin', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Admin(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetUserDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/GetUserDetails',
            admin__pb2.GetUserDetailsReq.SerializeToString,
            admin__pb2.UserDetails.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/GetUser',
            admin__pb2.GetUserReq.SerializeToString,
            api__pb2.User.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SearchUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/SearchUsers',
            admin__pb2.SearchUsersReq.SerializeToString,
            admin__pb2.SearchUsersRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChangeUserGender(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/ChangeUserGender',
            admin__pb2.ChangeUserGenderReq.SerializeToString,
            admin__pb2.UserDetails.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChangeUserBirthdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/ChangeUserBirthdate',
            admin__pb2.ChangeUserBirthdateReq.SerializeToString,
            admin__pb2.UserDetails.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddBadge(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/AddBadge',
            admin__pb2.AddBadgeReq.SerializeToString,
            admin__pb2.UserDetails.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveBadge(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/RemoveBadge',
            admin__pb2.RemoveBadgeReq.SerializeToString,
            admin__pb2.UserDetails.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetPassportSexGenderException(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/SetPassportSexGenderException',
            admin__pb2.SetPassportSexGenderExceptionReq.SerializeToString,
            admin__pb2.UserDetails.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BanUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/BanUser',
            admin__pb2.BanUserReq.SerializeToString,
            admin__pb2.UserDetails.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnbanUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/UnbanUser',
            admin__pb2.UnbanUserReq.SerializeToString,
            admin__pb2.UserDetails.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ShadowUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/ShadowUser',
            admin__pb2.ShadowUserReq.SerializeToString,
            admin__pb2.UserDetails.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnshadowUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/UnshadowUser',
            admin__pb2.UnshadowUserReq.SerializeToString,
            admin__pb2.UserDetails.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddAdminNote(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/AddAdminNote',
            admin__pb2.AddAdminNoteReq.SerializeToString,
            admin__pb2.UserDetails.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetContentReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/GetContentReport',
            admin__pb2.GetContentReportReq.SerializeToString,
            admin__pb2.GetContentReportRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetContentReportsForAuthor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/GetContentReportsForAuthor',
            admin__pb2.GetContentReportsForAuthorReq.SerializeToString,
            admin__pb2.GetContentReportsForAuthorRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendModNote(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/SendModNote',
            admin__pb2.SendModNoteReq.SerializeToString,
            admin__pb2.UserDetails.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MarkUserNeedsLocationUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/MarkUserNeedsLocationUpdate',
            admin__pb2.MarkUserNeedsLocationUpdateReq.SerializeToString,
            admin__pb2.UserDetails.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/DeleteUser',
            admin__pb2.DeleteUserReq.SerializeToString,
            admin__pb2.UserDetails.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RecoverDeletedUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/RecoverDeletedUser',
            admin__pb2.RecoverDeletedUserReq.SerializeToString,
            admin__pb2.UserDetails.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateApiKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/CreateApiKey',
            admin__pb2.CreateApiKeyReq.SerializeToString,
            admin__pb2.CreateApiKeyRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetChats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/GetChats',
            admin__pb2.GetChatsReq.SerializeToString,
            admin__pb2.GetChatsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteEvent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/DeleteEvent',
            admin__pb2.DeleteEventReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUserIds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/ListUserIds',
            admin__pb2.ListUserIdsReq.SerializeToString,
            admin__pb2.ListUserIdsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EditReferenceText(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/EditReferenceText',
            admin__pb2.EditReferenceTextReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteReference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/DeleteReference',
            admin__pb2.DeleteReferenceReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserReferences(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/GetUserReferences',
            admin__pb2.GetUserReferencesReq.SerializeToString,
            admin__pb2.GetUserReferencesRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFriendRequests(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/GetFriendRequests',
            admin__pb2.GetFriendRequestsReq.SerializeToString,
            admin__pb2.GetFriendRequestsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNonvisibleUserAccessLog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/GetNonvisibleUserAccessLog',
            admin__pb2.GetNonvisibleUserAccessLogReq.SerializeToString,
            admin__pb2.GetNonvisibleUserAccessLogRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EditDiscussion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/EditDiscussion',
            admin__pb2.EditDiscussionReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDiscussion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/DeleteDiscussion',
            admin__pb2.AdminDeleteDiscussionReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EditReply(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/EditReply',
            admin__pb2.EditReplyReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddUsersToModerationUserList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/AddUsersToModerationUserList',
            admin__pb2.AddUsersToModerationUserListReq.SerializeToString,
            admin__pb2.AddUsersToModerationUserListRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveUserFromModerationUserList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/RemoveUserFromModerationUserList',
            admin__pb2.RemoveUserFromModerationUserListReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListModerationUserLists(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/ListModerationUserLists',
            admin__pb2.ListModerationUserListsReq.SerializeToString,
            admin__pb2.ListModerationUserListsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAccountDeletionLink(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/CreateAccountDeletionLink',
            admin__pb2.CreateAccountDeletionLinkReq.SerializeToString,
            admin__pb2.CreateAccountDeletionLinkRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AccessStats(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/AccessStats',
            admin__pb2.AccessStatsReq.SerializeToString,
            admin__pb2.AccessStatsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetLastDonated(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/SetLastDonated',
            admin__pb2.SetLastDonatedReq.SerializeToString,
            admin__pb2.UserDetails.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAdminTag(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/CreateAdminTag',
            admin__pb2.CreateAdminTagReq.SerializeToString,
            admin__pb2.AdminTagInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAdminTags(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/ListAdminTags',
            admin__pb2.ListAdminTagsReq.SerializeToString,
            admin__pb2.ListAdminTagsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddAdminTagToUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/AddAdminTagToUser',
            admin__pb2.AddAdminTagToUserReq.SerializeToString,
            admin__pb2.UserDetails.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveAdminTagFromUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/RemoveAdminTagFromUser',
            admin__pb2.RemoveAdminTagFromUserReq.SerializeToString,
            admin__pb2.UserDetails.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetModScore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/SetModScore',
            admin__pb2.SetModScoreReq.SerializeToString,
            admin__pb2.UserDetails.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAdminActions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/ListAdminActions',
            admin__pb2.ListAdminActionsReq.SerializeToString,
            admin__pb2.ListAdminActionsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUserUploads(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/ListUserUploads',
            admin__pb2.ListUserUploadsReq.SerializeToString,
            admin__pb2.ListUserUploadsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOTAPackage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/CreateOTAPackage',
            admin__pb2.CreateOTAPackageReq.SerializeToString,
            admin__pb2.OTAPackage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOTAPackages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/ListOTAPackages',
            admin__pb2.ListOTAPackagesReq.SerializeToString,
            admin__pb2.ListOTAPackagesRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BanOTAPackage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.admin.Admin/BanOTAPackage',
            admin__pb2.BanOTAPackageReq.SerializeToString,
            admin__pb2.OTAPackage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: moderation.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import admin_pb2 as admin__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10moderation.proto\x12\x17org.couchers.moderation\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x0b\x61\x64min.proto\x1a\x11\x61nnotations.proto\"\x80\x03\n\x13ModerationStateInfo\x12\x1b\n\x13moderation_state_id\x18\x01 \x01(\x03\x12\x42\n\x0bobject_type\x18\x02 \x01(\x0e\x32-.org.couchers.moderation.ModerationObjectType\x12\x11\n\tobject_id\x18\x03 \x01(\x03\x12\x41\n\nvisibility\x18\x04 \x01(\x0e\x32-.org.couchers.moderation.ModerationVisibility\x12+\n\x07\x63reated\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07updated\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0e\x61uthor_user_id\x18\x07 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x08 \x01(\t\x12/\n\x06\x61uthor\x18\t \x01(\x0b\x32\x1f.org.couchers.admin.UserDetails\"\xd7\x02\n\x17ModerationQueueItemInfo\x12\x15\n\rqueue_item_id\x18\x01 \x01(\x03\x12\x1b\n\x13moderation_state_id\x18\x02 \x01(\x03\x12\x30\n\x0ctime_created\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x07trigger\x18\x04 \x01(\x0e\x32*.org.couchers.moderation.ModerationTrigger\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x13\n\x0bis_resolved\x18\x06 \x01(\x08\x12\x1a\n\x12resolved_by_log_id\x18\x07 \x01(\x03\x12\x46\n\x10moderation_state\x18\x08 \x01(\x0b\x32,.org.couchers.moderation.ModerationStateInfo\x12\x10\n\x08priority\x18\t \x01(\x05\"\xcf\x02\n\x16ModerationLogEntryInfo\x12\x14\n\x0clog_entry_id\x18\x01 \x01(\x03\x12\x1b\n\x13moderation_state_id\x18\x02 \x01(\x03\x12(\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x06\x61\x63tion\x18\x04 \x01(\x0e\x32).org.couchers.moderation.ModerationAction\x12\x19\n\x11moderator_user_id\x18\x05 \x01(\x03\x12\x45\n\x0enew_visibility\x18\x06 \x01(\x0e\x32-.org.couchers.moderation.ModerationVisibility\x12\x0e\n\x06reason\x18\x07 \x01(\t\x12\x14\n\x0cnew_priority\x18\x08 \x01(\x05\x12\x15\n\rqueue_item_id\x18\t \x01(\x03\"\xcb\x03\n\x15GetModerationQueueReq\x12<\n\x08triggers\x18\x04 \x03(\x0e\x32*.org.couchers.moderation.ModerationTrigger\x12\x42\n\x0bobject_type\x18\x05 \x01(\x0e\x32-.org.couchers.moderation.ModerationObjectType\x12\x17\n\x0funresolved_only\x18\x06 \x01(\x08\x12\x32\n\x0e\x63reated_before\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rcreated_after\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1b\n\x13item_author_user_id\x18\t \x01(\x03\x12\x19\n\x0cpriority_min\x18\n \x01(\x05H\x00\x88\x01\x01\x12\x19\n\x0cpriority_max\x18\x0b \x01(\x05H\x01\x88\x01\x01\x12\x11\n\tpage_size\x18\x01 \x01(\r\x12\x12\n\npage_token\x18\x02 \x01(\t\x12\x14\n\x0cnewest_first\x18\x03 \x01(\x08\x42\x0f\n\r_priority_minB\x0f\n\r_priority_max\"w\n\x15GetModerationQueueRes\x12\x45\n\x0bqueue_items\x18\x01 \x03(\x0b\x32\x30.org.couchers.moderation.ModerationQueueItemInfo\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"n\n\x15GetModerationStateReq\x12\x42\n\x0bobject_type\x18\x01 \x01(\x0e\x32-.org.couchers.moderation.ModerationObjectType\x12\x11\n\tobject_id\x18\x02 \x01(\x03\"_\n\x15GetModerationStateRes\x12\x46\n\x10moderation_state\x18\x01 \x01(\x0b\x32,.org.couchers.moderation.ModerationStateInfo\"2\n\x13GetModerationLogReq\x12\x1b\n\x13moderation_state_id\x18\x01 \x01(\x03\"\xa3\x01\n\x13GetModerationLogRes\x12\x44\n\x0blog_entries\x18\x01 \x03(\x0b\x32/.org.couchers.moderation.ModerationLogEntryInfo\x12\x46\n\x10moderation_state\x18\x02 \x01(\x0b\x32,.org.couchers.moderation.ModerationStateInfo\"\xdb\x02\n\x12ModerateContentReq\x12\x1b\n\x13moderation_state_id\x18\x01 \x01(\x03\x12\x39\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32).org.couchers.moderation.ModerationAction\x12\x41\n\nvisibility\x18\x03 \x01(\x0e\x32-.org.couchers.moderation.ModerationVisibility\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x10\n\x08priority\x18\x05 \x01(\x05\x12\x15\n\rqueue_item_id\x18\x06 \x01(\x03\x12;\n\x07trigger\x18\x07 \x01(\x0e\x32*.org.couchers.moderation.ModerationTrigger\x12\x1f\n\x17supersede_queue_item_id\x18\x08 \x01(\x03\x12\x13\n\x0b\x63lear_flags\x18\t \x01(\x08\"\\\n\x12ModerateContentRes\x12\x46\n\x10moderation_state\x18\x01 \x01(\x0b\x32,.org.couchers.moderation.ModerationStateInfo\"\xc9\x01\n\x1bSetUserContentVisibilityReq\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x41\n\nvisibility\x18\x02 \x01(\x0e\x32-.org.couchers.moderation.ModerationVisibility\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12\x46\n\x0f\x66rom_visibility\x18\x04 \x03(\x0e\x32-.org.couchers.moderation.ModerationVisibility\"4\n\x1bSetUserContentVisibilityRes\x12\x15\n\rupdated_count\x18\x01 \x01(\x03\"n\n\x17ListModerationStatesReq\x12\x16\n\x0e\x61uthor_user_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x14\n\x0cnewest_first\x18\x04 \x01(\x08\"{\n\x17ListModerationStatesRes\x12G\n\x11moderation_states\x18\x01 \x03(\x0b\x32,.org.couchers.moderation.ModerationStateInfo\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t*\xca\x01\n\x14ModerationVisibility\x12%\n!MODERATION_VISIBILITY_UNSPECIFIED\x10\x00\x12 \n\x1cMODERATION_VISIBILITY_HIDDEN\x10\x01\x12\"\n\x1eMODERATION_VISIBILITY_SHADOWED\x10\x02\x12!\n\x1dMODERATION_VISIBILITY_VISIBLE\x10\x03\x12\"\n\x1eMODERATION_VISIBILITY_UNLISTED\x10\x04*\xce\x01\n\x11ModerationTrigger\x12\"\n\x1eMODERATION_TRIGGER_UNSPECIFIED\x10\x00\x12%\n!MODERATION_TRIGGER_INITIAL_REVIEW\x10\x01\x12 \n\x1cMODERATION_TRIGGER_USER_FLAG\x10\x02\x12#\n\x1fMODERATION_TRIGGER_MACHINE_FLAG\x10\x03\x12\'\n#MODERATION_TRIGGER_MODERATOR_REVIEW\x10\x04*\x97\x02\n\x10ModerationAction\x12!\n\x1dMODERATION_ACTION_UNSPECIFIED\x10\x00\x12\x1c\n\x18MODERATION_ACTION_CREATE\x10\x01\x12\x1d\n\x19MODERATION_ACTION_APPROVE\x10\x02\x12\x1a\n\x16MODERATION_ACTION_HIDE\x10\x03\x12\x1a\n\x16MODERATION_ACTION_FLAG\x10\x04\x12\x1c\n\x18MODERATION_ACTION_UNFLAG\x10\x05\x12)\n%MODERATION_ACTION_BULK_SET_VISIBILITY\x10\x06\x12\"\n\x1eMODERATION_ACTION_SET_PRIORITY\x10\x07*\xf9\x02\n\x14ModerationObjectType\x12&\n\"MODERATION_OBJECT_TYPE_UNSPECIFIED\x10\x00\x12\'\n#MODERATION_OBJECT_TYPE_HOST_REQUEST\x10\x01\x12%\n!MODERATION_OBJECT_TYPE_GROUP_CHAT\x10\x02\x12)\n%MODERATION_OBJECT_TYPE_FRIEND_REQUEST\x10\x03\x12+\n\'MODERATION_OBJECT_TYPE_EVENT_OCCURRENCE\x10\x04\x12\"\n\x1eMODERATION_OBJECT_TYPE_COMMENT\x10\x05\x12 \n\x1cMODERATION_OBJECT_TYPE_REPLY\x10\x06\x12%\n!MODERATION_OBJECT_TYPE_DISCUSSION\x10\x07\x12$\n MODERATION_OBJECT_TYPE_REFERENCE\x10\x08\x32\xec\x05\n\nModeration\x12v\n\x12GetModerationQueue\x12..org.couchers.moderation.GetModerationQueueReq\x1a..org.couchers.moderation.GetModerationQueueRes\"\x00\x12v\n\x12GetModerationState\x12..org.couchers.moderation.GetModerationStateReq\x1a..org.couchers.moderation.GetModerationStateRes\"\x00\x12p\n\x10GetModerationLog\x12,.org.couchers.moderation.GetModerationLogReq\x1a,.org.couchers.moderation.GetModerationLogRes\"\x00\x12m\n\x0fModerateContent\x12+.org.couchers.moderation.ModerateContentReq\x1a+.org.couchers.moderation.ModerateContentRes\"\x00\x12\x88\x01\n\x18SetUserContentVisibility\x12\x34.org.couchers.moderation.SetUserContentVisibilityReq\x1a\x34.org.couchers.moderation.SetUserContentVisibilityRes\"\x00\x12|\n\x14ListModerationStates\x12\x30.org.couchers.moderation.ListModerationStatesReq\x1a\x30.org.couchers.moderation.ListModerationStatesRes\"\x00\x1a\x04\x88\xb5\x18\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'moderation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MODERATION']._loaded_options = None
  _globals['_MODERATION']._serialized_options = b'\210\265\030\004'
  _globals['_MODERATIONVISIBILITY']._serialized_start=3131
  _globals['_MODERATIONVISIBILITY']._serialized_end=3333
  _globals['_MODERATIONTRIGGER']._serialized_start=3336
  _globals['_MODERATIONTRIGGER']._serialized_end=3542
  _globals['_MODERATIONACTION']._serialized_start=3545
  _globals['_MODERATIONACTION']._serialized_end=3824
  _globals['_MODERATIONOBJECTTYPE']._serialized_start=3827
  _globals['_MODERATIONOBJECTTYPE']._serialized_end=4204
  _globals['_MODERATIONSTATEINFO']._serialized_start=111
  _globals['_MODERATIONSTATEINFO']._serialized_end=495
  _globals['_MODERATIONQUEUEITEMINFO']._serialized_start=498
  _globals['_MODERATIONQUEUEITEMINFO']._serialized_end=841
  _globals['_MODERATIONLOGENTRYINFO']._serialized_start=844
  _globals['_MODERATIONLOGENTRYINFO']._serialized_end=1179
  _globals['_GETMODERATIONQUEUEREQ']._serialized_start=1182
  _globals['_GETMODERATIONQUEUEREQ']._serialized_end=1641
  _globals['_GETMODERATIONQUEUERES']._serialized_start=1643
  _globals['_GETMODERATIONQUEUERES']._serialized_end=1762
  _globals['_GETMODERATIONSTATEREQ']._serialized_start=1764
  _globals['_GETMODERATIONSTATEREQ']._serialized_end=1874
  _globals['_GETMODERATIONSTATERES']._serialized_start=1876
  _globals['_GETMODERATIONSTATERES']._serialized_end=1971
  _globals['_GETMODERATIONLOGREQ']._serialized_start=1973
  _globals['_GETMODERATIONLOGREQ']._serialized_end=2023
  _globals['_GETMODERATIONLOGRES']._serialized_start=2026
  _globals['_GETMODERATIONLOGRES']._serialized_end=2189
  _globals['_MODERATECONTENTREQ']._serialized_start=2192
  _globals['_MODERATECONTENTREQ']._serialized_end=2539
  _globals['_MODERATECONTENTRES']._serialized_start=2541
  _globals['_MODERATECONTENTRES']._serialized_end=2633
  _globals['_SETUSERCONTENTVISIBILITYREQ']._serialized_start=2636
  _globals['_SETUSERCONTENTVISIBILITYREQ']._serialized_end=2837
  _globals['_SETUSERCONTENTVISIBILITYRES']._serialized_start=2839
  _globals['_SETUSERCONTENTVISIBILITYRES']._serialized_end=2891
  _globals['_LISTMODERATIONSTATESREQ']._serialized_start=2893
  _globals['_LISTMODERATIONSTATESREQ']._serialized_end=3003
  _globals['_LISTMODERATIONSTATESRES']._serialized_start=3005
  _globals['_LISTMODERATIONSTATESRES']._serialized_end=3128
  _globals['_MODERATION']._serialized_start=4207
  _globals['_MODERATION']._serialized_end=4955
# @@protoc_insertion_point(module_scope)
